######
Mizani
######

=================    =================
Latest Release       |release|_
License              |license|_
Build Status         |buildstatus|_
Coverage             |coverage|_
Documentation        |documentation|_
=================    =================

Mizani is a scales package for graphics. It is written in Python and is
based on Hadley Wickham's `Scales`_. For how to use it in a graphics
system, see the `documentation`_.

Installation
============

**Official version**

.. code-block:: console

   $ pip install mizani

**Development version**

.. code-block:: console

   $ pip install git+https://github.com/has2k1/mizani.git@master



.. |release| image:: https://img.shields.io/pypi/v/mizani.svg
.. _release: https://pypi.python.org/pypi/mizani

.. |license| image:: https://img.shields.io/pypi/l/mizani.svg
.. _license: https://pypi.python.org/pypi/mizani

.. |buildstatus| image:: https://api.travis-ci.org/has2k1/mizani.svg?branch=master
.. _buildstatus: https://travis-ci.org/has2k1/mizani

.. |coverage| image:: https://coveralls.io/repos/github/has2k1/mizani/badge.svg?branch=master
.. _coverage: https://coveralls.io/github/has2k1/mizani?branch=master

.. |documentation| image:: https://readthedocs.org/projects/mizani/badge/?version=latest
.. _documentation: https://mizani.readthedocs.io/en/latest/

.. _Scales: https://github.com/hadley/scales
